@@ -43,8 +43,8 @@ class Psycopg2Driver(db.drivers.Driver):
         parsed = urlparse.urlparse(url)
         db_name = parsed.path[1:].split("?", 1)[0]
         addl_kwargs = cls._get_kwargs(url)
-        if parsed.scheme in ("postgresql", "postgres"):
-            warnings.warn("Parsed scheme 'postgresql' or 'postgres', strange things may happen: %s" % url)
+        if parsed.scheme not in ("postgresql", "postgres"):
+            warnings.warn("Parsed scheme '%s' not one of 'postgresql' or 'postgres', strange things may happen: %s" % (parsed.scheme, url))
         return cls(dbname=db_name,
                    user=parsed.username,
                    password=parsed.password,
